#!/bin/sh
# build.sh
# LinuxSampler
#
# Created by Toshi Nagata on 07/04/18.
# Copyright 2007 __MyCompanyName__. All rights reserved.

PROJDIR=$PWD

function link_recursive () {
	local arg base
	arg="$1"
	base=`basename $arg`
	if test -d "$arg"; then
		echo "Copying directory $arg"
		mkdir -p "$base"
		cd "$base"
		if ! expr $arg : "^/"; then
			arg="../$arg"
		fi
		for i in $arg/*; do
			link_recursive $i
		done
		cd ..
	else
	#	echo "Linking $arg"
		ln -sf $arg
	fi
}

ARG1="$1"

#  Sanity checks
if test "x$BUILD_STYLE" = "x"; then
    echo "BUILD_STYLE is empty."
    exit 1
fi
if test "x$TARGET_NAME" = "x"; then
    echo "TARGET_NAME is empty."
    exit 1
fi
if test "x$ARG1" = "x"; then
	echo "Missing argument: Usage: $0 source-dir"
	exit 1
fi
if test ! -d "$ARG1"; then
    echo "The target source directory (should be \"$ARG1\") does not exist."
    exit 1
fi
if test "x$TARGET_TEMP_DIR" = "x"; then
    TARGET_TEMP_DIR=$PROJDIR/build/$ARG1.build/$BUILD_STYLE
    mkdir -p "$TARGET_TEMP_DIR"
fi
if test ! -d "$TARGET_TEMP_DIR"; then
    echo "TARGET_TEMP_DIR ($TARGET_TEMP_DIR) does not exist."
    exit 1
fi

if test -e "$SDKROOT"; then
	SYSROOT_CFLAGS="-isysroot $SDKROOT"
else
	SYSROOT_CFLAGS=
fi
PATH="/usr/local/bin:$PATH"

ARCH_CFLAGS=""
ARCH_CONFIG_OPTIONS=""
case "$BUILD_STYLE" in
    *ppc)
	ARCH="ppc"
	ARCH_CFLAGS="-arch ppc"
	;;
    *i386)
	ARCH="i386"
	ARCH_CFLAGS="-arch i386 -msse -msse2"
	ARCH_CONFIG_OPTIONS="--host=i386-apple-darwin8"
	;;
    *UB|*Universal)
	ARCH="UB"
	;;
    *)
	echo "Warning: architecture cannot be recognized from the build style"
	ARCH="unknown"
	;;
esac

case "$BUILD_STYLE" in
    Development|Default)
	OPT_CFLAGS="-O2 -g"
	;;
    Deployment*)
	OPT_CFLAGS="-O3"
	;;
esac

export CFLAGS="$SYSROOT_CFLAGS $ARCH_CFLAGS $OPT_CFLAGS $CFLAGS"
export CXXFLAGS="$SYSROOT_CFLAGS $ARCH_CFLAGS $OPT_CFLAGS $CXXFLAGS"

#  Display all environments
set

#  Clean if specified
if test "x$ACTION" = "xclean"; then
	if test "x$MAKE_INSTALL" != "x"; then
		make uninstall
	fi
    echo "Removing files in $TARGET_TEMP_DIR"
    rm -rf $TARGET_TEMP_DIR/*
    exit $?
fi

if test "x$ACTION" = "xbuild"; then

	#  Copy the source files if necessary
	mkdir -p "$TARGET_TEMP_DIR"
	cd "$TARGET_TEMP_DIR"
	if test ! -e Makefile -a ! -e configure -a ! -e Makefile.cvs; then
		echo "Copying $PROJDIR/$ARG1 to $TARGET_TEMP_DIR"
		for i in $PROJDIR/$ARG1/*; do
			link_recursive $i
		done
	fi

	#  Make ./configure if necessary
	if test -e Makefile.cvs -a ! -e configure; then
		echo "Running make -f Makefile.cvs"
		make -f Makefile.cvs || exit $?
	fi

	#  Run ./configure if necessary
	if test -e configure -a ! -e Makefile; then
		CONFIG_ARGS="$CONFIG_OPTIONS $ARCH_CONFIG_OPTIONS $CONFIG_ENVS"
		echo "Running configure $CONFIG_ARGS"
		./configure $CONFIG_ARGS || exit $?
	fi

	#  make
	echo "Running make"
	make || exit $?

fi

#  make install if specified
if test "x$ACTION" = "install" -o "x$WITH_INSTALL" != "x"; then
    echo "Running make install"
    make install || exit $?
fi
